@@ -1,6 +1,7 @@
 
+#' @importFrom stats sd
 #' @export
-logCV<-function(data, log_transformed){
+protLogCV<-function(data, log_transformed){
   if(log_transformed=="no"){
      cv=apply(log(data), 1, function(x) sqrt(exp(stats::sd(x, na.rm = TRUE)^2)-1))*100
   }
@@ -9,3 +10,8 @@ logCV<-function(data, log_transformed){
   }
   cv
 }
+
+#' @export
+protCV<-function(data){
+    cv=apply(data, 1, function(x) sd(x)/mean(x))*100
+}
